import json

import pytest

from tests.rest import utils


@pytest.fixture
def student_credentials() -> str:
    return json.dumps({
        "type": "user",
        "username": "student1",
        "password": "123456"
    })


@pytest.fixture
def teacher_credentials() -> str:
    return json.dumps({
        "type": "user",
        "username": "teacher2",
        "password": "123123"
    })


def test_project_detail_using_admin_cred(client):
    path = f'/courses/TestCourse1'
    response = utils.make_request(client, path, 'get')
    assert response.status_code == 200
    assert response.mimetype == 'application/json'


def test_project_detail_using_student_cred(client, student_credentials):
    path = f'/courses/TestCourse1'
    response = utils.make_request(client, path, 'get', credentials=student_credentials)
    print(f"Response: {response.data}")
    assert response.status_code == 200
    assert response.mimetype == 'application/json'


def test_project_detail_using_teacher_cred(client, teacher_credentials):
    path = f'/courses/TestCourse1/projects'
    response = utils.make_request(client, path, 'get', credentials=teacher_credentials)
    print(f"Response: {response.data}")
    assert response.status_code == 200
    assert response.mimetype == 'application/json'
